@@ -20,6 +20,9 @@
 #ifndef GTK_SOURCE_H
 #define GTK_SOURCE_H
 
+#define GTK_SOURCE_H_INSIDE
+
+#include <gtksourceview/completion-providers/words/gtksourcecompletionwords.h>
 #include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourcebuffer.h>
 #include <gtksourceview/gtksourcecompletioncontext.h>
@@ -45,6 +48,7 @@
 #include <gtksourceview/gtksourceregion.h>
 #include <gtksourceview/gtksourcesearchcontext.h>
 #include <gtksourceview/gtksourcesearchsettings.h>
+#include <gtksourceview/gtksourcespacedrawer.h>
 #include <gtksourceview/gtksourcestyle.h>
 #include <gtksourceview/gtksourcestylescheme.h>
 #include <gtksourceview/gtksourcestyleschemechooser.h>
@@ -59,4 +63,6 @@
 #include <gtksourceview/gtksourceview-enumtypes.h>
 #include <gtksourceview/gtksourceautocleanups.h>
 
+#undef GTK_SOURCE_H_INSIDE
+
 #endif /* GTK_SOURCE_H */
