@@ -2028,7 +2028,7 @@ init_tree_view (GtkSourceCompletion *completion,
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell_renderer;
 	GtkStyleContext *style_context;
-	GdkRGBA* background_color = NULL;
+	GdkRGBA background_color;
 	GdkRGBA foreground_color;
 
 	completion->priv->tree_view_proposals = GTK_TREE_VIEW (gtk_builder_get_object (builder, "tree_view_proposals"));
@@ -2094,7 +2094,7 @@ init_tree_view (GtkSourceCompletion *completion,
 	gtk_style_context_restore (style_context);
 
 	g_object_set (cell_renderer,
-	              "cell-background-rgba", background_color,
+	              "cell-background-rgba", &background_color,
 	              NULL);
 
 	g_object_bind_property (completion, "show-icons",
@@ -2116,7 +2116,7 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", background_color,
+	              "cell-background-rgba", &background_color,
 	              NULL);
 
 	/* Accelerators cell renderer */
@@ -2132,7 +2132,7 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", background_color,
+	              "cell-background-rgba", &background_color,
 		      NULL);
 
 	gtk_tree_view_column_set_cell_data_func (column,
@@ -2146,8 +2146,6 @@ init_tree_view (GtkSourceCompletion *completion,
 				 G_CALLBACK (accelerators_notify_cb),
 				 column,
 				 0);
-
-	gdk_rgba_free (background_color);
 }
 
 static void
@@ -3059,37 +3057,6 @@ gtk_source_completion_create_context (GtkSourceCompletion *completion,
 	return _gtk_source_completion_context_new (completion, &iter);
 }
 
-/**
- * gtk_source_completion_move_window:
- * @completion: a #GtkSourceCompletion.
- * @iter: a #GtkTextIter.
- *
- * Move the completion window to a specific iter.
- *
- * Deprecated: 3.8: Use gtk_source_completion_provider_get_start_iter() instead.
- */
-void
-gtk_source_completion_move_window (GtkSourceCompletion *completion,
-                                   GtkTextIter         *iter)
-{
-	g_return_if_fail (GTK_SOURCE_IS_COMPLETION (completion));
-	g_return_if_fail (iter != NULL);
-
-	if (completion->priv->view == NULL)
-	{
-		return;
-	}
-
-	if (!gtk_widget_get_visible (GTK_WIDGET (completion->priv->main_window)))
-	{
-		return;
-	}
-
-	gtk_source_completion_info_move_to_iter (completion->priv->main_window,
-	                                         GTK_TEXT_VIEW (completion->priv->view),
-	                                         iter);
-}
-
 /**
  * gtk_source_completion_block_interactive:
  * @completion: a #GtkSourceCompletion.
