@@ -23,6 +23,10 @@
 #ifndef GTK_SOURCE_COMPLETION_INFO_H
 #define GTK_SOURCE_COMPLETION_INFO_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
 
@@ -50,7 +54,7 @@ struct _GtkSourceCompletionInfoClass
 {
 	GtkWindowClass parent_class;
 
-	void	(*before_show)		(GtkSourceCompletionInfo *info);
+	gpointer padding[10];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
@@ -65,13 +69,6 @@ void		 gtk_source_completion_info_move_to_iter	(GtkSourceCompletionInfo *info,
 								 GtkTextView             *view,
 								 GtkTextIter             *iter);
 
-GTK_SOURCE_DEPRECATED_IN_3_8_FOR (gtk_container_add)
-void		 gtk_source_completion_info_set_widget		(GtkSourceCompletionInfo *info,
-								 GtkWidget               *widget);
-
-GTK_SOURCE_DEPRECATED_IN_3_8_FOR (gtk_bin_get_child)
-GtkWidget	*gtk_source_completion_info_get_widget		(GtkSourceCompletionInfo *info);
-
 G_GNUC_INTERNAL
 void		 _gtk_source_completion_info_set_xoffset	(GtkSourceCompletionInfo *info,
 								 gint                     xoffset);
