@@ -23,6 +23,10 @@
 #ifndef GTK_SOURCE_COMPLETION_PROVIDER_H
 #define GTK_SOURCE_COMPLETION_PROVIDER_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcecompletioncontext.h>
 #include <gtksourceview/gtksourcetypes.h>
