@@ -23,6 +23,10 @@
 #ifndef GTK_SOURCE_ENCODING_H
 #define GTK_SOURCE_ENCODING_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <glib.h>
 #include <glib-object.h>
 #include <gtksourceview/gtksourcetypes.h>
