@@ -23,11 +23,7 @@
 #define GTK_SOURCE_FILE_H
 
 #if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
-#  if defined (__GNUC__)
-#    warning "Only <gtksourceview/gtksource.h> can be included directly."
-#  elif defined (G_OS_WIN32)
-#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
-#  endif
+#error "Only <gtksourceview/gtksource.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
@@ -45,6 +41,48 @@ G_BEGIN_DECLS
 typedef struct _GtkSourceFileClass    GtkSourceFileClass;
 typedef struct _GtkSourceFilePrivate  GtkSourceFilePrivate;
 
+/**
+ * GtkSourceNewlineType:
+ * @GTK_SOURCE_NEWLINE_TYPE_LF: line feed, used on UNIX.
+ * @GTK_SOURCE_NEWLINE_TYPE_CR: carriage return, used on Mac.
+ * @GTK_SOURCE_NEWLINE_TYPE_CR_LF: carriage return followed by a line feed, used
+ *   on Windows.
+ *
+ * Since: 3.14
+ */
+typedef enum _GtkSourceNewlineType
+{
+	GTK_SOURCE_NEWLINE_TYPE_LF,
+	GTK_SOURCE_NEWLINE_TYPE_CR,
+	GTK_SOURCE_NEWLINE_TYPE_CR_LF
+} GtkSourceNewlineType;
+
+/**
+ * GTK_SOURCE_NEWLINE_TYPE_DEFAULT:
+ *
+ * The default newline type on the current OS.
+ *
+ * Since: 3.14
+ */
+#ifdef G_OS_WIN32
+#define GTK_SOURCE_NEWLINE_TYPE_DEFAULT GTK_SOURCE_NEWLINE_TYPE_CR_LF
+#else
+#define GTK_SOURCE_NEWLINE_TYPE_DEFAULT GTK_SOURCE_NEWLINE_TYPE_LF
+#endif
+
+/**
+ * GtkSourceCompressionType:
+ * @GTK_SOURCE_COMPRESSION_TYPE_NONE: plain text.
+ * @GTK_SOURCE_COMPRESSION_TYPE_GZIP: gzip compression.
+ *
+ * Since: 3.14
+ */
+typedef enum _GtkSourceCompressionType
+{
+	GTK_SOURCE_COMPRESSION_TYPE_NONE,
+	GTK_SOURCE_COMPRESSION_TYPE_GZIP
+} GtkSourceCompressionType;
+
 /**
  * GtkSourceMountOperationFactory:
  * @file: a #GtkSourceFile.
