@@ -48,7 +48,6 @@ enum
 {
 	PROP_0,
 	PROP_PIXBUF,
-	PROP_STOCK_ID,
 	PROP_ICON_NAME,
 	PROP_GICON,
 };
@@ -64,23 +63,15 @@ center_on (GtkSourceGutterRenderer *renderer,
            gint                    *x,
            gint                    *y)
 {
+	GdkRectangle location;
 	GtkTextView *view;
-	GtkTextWindowType window_type;
-	GdkRectangle buffer_location;
-	gint window_y;
 
 	view = gtk_source_gutter_renderer_get_view (renderer);
-	window_type = gtk_source_gutter_renderer_get_window_type (renderer);
 
-	gtk_text_view_get_iter_location (view, iter, &buffer_location);
-
-	gtk_text_view_buffer_to_window_coords (view,
-					       window_type,
-					       0, buffer_location.y,
-					       NULL, &window_y);
+	gtk_text_view_get_iter_location (view, iter, &location);
 
 	*x = cell_area->x + (cell_area->width - width) * xalign;
-	*y = window_y + (buffer_location.height - height) * yalign;
+	*y = cell_area->y + (location.height - height) * yalign;
 }
 
 static void
@@ -215,18 +206,6 @@ set_pixbuf (GtkSourceGutterRendererPixbuf *renderer,
 	gtk_source_gutter_renderer_queue_draw (GTK_SOURCE_GUTTER_RENDERER (renderer));
 }
 
-static void
-set_stock_id (GtkSourceGutterRendererPixbuf *renderer,
-              const gchar                   *stock_id)
-{
-	gtk_source_pixbuf_helper_set_stock_id (renderer->priv->helper,
-	                                       stock_id);
-
-	g_object_notify (G_OBJECT (renderer), "stock-id");
-
-	gtk_source_gutter_renderer_queue_draw (GTK_SOURCE_GUTTER_RENDERER (renderer));
-}
-
 static void
 set_gicon (GtkSourceGutterRendererPixbuf *renderer,
            GIcon                         *icon)
@@ -267,9 +246,6 @@ gtk_source_gutter_renderer_pixbuf_set_property (GObject      *object,
 		case PROP_PIXBUF:
 			set_pixbuf (renderer, g_value_get_object (value));
 			break;
-		case PROP_STOCK_ID:
-			set_stock_id (renderer, g_value_get_string (value));
-			break;
 		case PROP_ICON_NAME:
 			set_icon_name (renderer, g_value_get_string (value));
 			break;
@@ -298,10 +274,6 @@ gtk_source_gutter_renderer_pixbuf_get_property (GObject    *object,
 			g_value_set_object (value,
 			                    gtk_source_pixbuf_helper_get_pixbuf (renderer->priv->helper));
 			break;
-		case PROP_STOCK_ID:
-			g_value_set_string (value,
-			                    gtk_source_pixbuf_helper_get_stock_id (renderer->priv->helper));
-			break;
 		case PROP_ICON_NAME:
 			g_value_set_string (value,
 			                    gtk_source_pixbuf_helper_get_icon_name (renderer->priv->helper));
@@ -337,21 +309,6 @@ gtk_source_gutter_renderer_pixbuf_class_init (GtkSourceGutterRendererPixbufClass
 	                                                      GDK_TYPE_PIXBUF,
 	                                                      G_PARAM_READWRITE));
 
-	/**
-	 * GtkSourceGutterRendererPixbuf:stock-id:
-	 *
-	 * The stock id.
-	 *
-	 * Deprecated: 3.10: Don't use this property.
-	 */
-	g_object_class_install_property (object_class,
-	                                 PROP_STOCK_ID,
-	                                 g_param_spec_string ("stock-id",
-	                                                      "Stock Id",
-	                                                      "The stock id",
-	                                                      NULL,
-	                                                      G_PARAM_READWRITE | G_PARAM_DEPRECATED));
-
 	g_object_class_install_property (object_class,
 	                                 PROP_ICON_NAME,
 	                                 g_param_spec_string ("icon-name",
@@ -424,37 +381,6 @@ gtk_source_gutter_renderer_pixbuf_get_pixbuf (GtkSourceGutterRendererPixbuf *ren
 	return gtk_source_pixbuf_helper_get_pixbuf (renderer->priv->helper);
 }
 
-/**
- * gtk_source_gutter_renderer_pixbuf_set_stock_id:
- * @renderer: a #GtkSourceGutterRendererPixbuf
- * @stock_id: (nullable): the stock id
- *
- * Deprecated: 3.10: Don't use this function.
- */
-void
-gtk_source_gutter_renderer_pixbuf_set_stock_id (GtkSourceGutterRendererPixbuf *renderer,
-                                                const gchar                   *stock_id)
-{
-	g_return_if_fail (GTK_SOURCE_IS_GUTTER_RENDERER_PIXBUF_CLASS (renderer));
-
-	set_stock_id (renderer, stock_id);
-}
-
-/**
- * gtk_source_gutter_renderer_pixbuf_get_stock_id:
- * @renderer: a #GtkSourceGutterRendererPixbuf
- *
- * Returns: the stock id.
- * Deprecated: 3.10: Don't use this function.
- */
-const gchar *
-gtk_source_gutter_renderer_pixbuf_get_stock_id (GtkSourceGutterRendererPixbuf *renderer)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_GUTTER_RENDERER_PIXBUF (renderer), NULL);
-
-	return gtk_source_pixbuf_helper_get_stock_id (renderer->priv->helper);
-}
-
 /**
  * gtk_source_gutter_renderer_pixbuf_set_gicon:
  * @renderer: a #GtkSourceGutterRendererPixbuf
