@@ -22,6 +22,10 @@
 #ifndef GTK_SOURCE_GUTTER_RENDERER_PIXBUF_H
 #define GTK_SOURCE_GUTTER_RENDERER_PIXBUF_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourcegutterrenderer.h>
 
@@ -53,7 +57,7 @@ struct _GtkSourceGutterRendererPixbufClass
 	/*< private >*/
 	GtkSourceGutterRendererClass parent_class;
 
-	/*< public >*/
+	gpointer padding[10];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
@@ -69,13 +73,6 @@ void         gtk_source_gutter_renderer_pixbuf_set_pixbuf       (GtkSourceGutter
 GTK_SOURCE_AVAILABLE_IN_ALL
 GdkPixbuf   *gtk_source_gutter_renderer_pixbuf_get_pixbuf       (GtkSourceGutterRendererPixbuf *renderer);
 
-GTK_SOURCE_DEPRECATED_IN_3_10
-void         gtk_source_gutter_renderer_pixbuf_set_stock_id     (GtkSourceGutterRendererPixbuf *renderer,
-                                                                 const gchar                   *stock_id);
-
-GTK_SOURCE_DEPRECATED_IN_3_10
-const gchar *gtk_source_gutter_renderer_pixbuf_get_stock_id     (GtkSourceGutterRendererPixbuf *renderer);
-
 GTK_SOURCE_AVAILABLE_IN_ALL
 void         gtk_source_gutter_renderer_pixbuf_set_gicon        (GtkSourceGutterRendererPixbuf *renderer,
                                                                  GIcon                         *icon);
