@@ -22,6 +22,10 @@
 #ifndef GTK_SOURCE_GUTTER_RENDERER_TEXT_H
 #define GTK_SOURCE_GUTTER_RENDERER_TEXT_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourcegutterrenderer.h>
 
@@ -53,7 +57,7 @@ struct _GtkSourceGutterRendererTextClass
 	/*< private >*/
 	GtkSourceGutterRendererClass parent_class;
 
-	/*< public >*/
+	gpointer padding[10];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
