@@ -228,7 +228,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language id",
 							      "Language id",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
@@ -236,7 +237,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language name",
 							      "Language name",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_SECTION,
@@ -244,7 +246,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 						 	      "Language section",
 							      "Language section",
 							      NULL,
-							      G_PARAM_READABLE));
+							      G_PARAM_READABLE |
+							      G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (object_class,
 					 PROP_HIDDEN,
@@ -252,7 +255,8 @@ gtk_source_language_class_init (GtkSourceLanguageClass *klass)
 							       "Hidden",
 							       "Whether the language should be hidden from the user",
 							       FALSE,
-							       G_PARAM_READABLE));
+							       G_PARAM_READABLE |
+							       G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -716,7 +720,10 @@ gtk_source_language_parse_file (GtkSourceLanguage *language)
 			switch (language->priv->version)
 			{
 				case GTK_SOURCE_LANGUAGE_VERSION_1_0:
-					success = _gtk_source_language_file_parse_version1 (language, ctx_data);
+					g_warning ("The language definition format version 1 "
+						   "(for syntax highlighting) is no longer "
+						   "supported by GtkSourceView >= 4.0. "
+						   "Please use version 2.");
 					break;
 
 				case GTK_SOURCE_LANGUAGE_VERSION_2_0:
