@@ -24,11 +24,7 @@
 #define GTK_SOURCE_MARK_ATTRIBUTES_H
 
 #if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
-#  if defined (__GNUC__)
-#    warning "Only <gtksourceview/gtksource.h> can be included directly."
-#  elif defined (G_OS_WIN32)
-#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
-#  endif
+#error "Only <gtksourceview/gtksource.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
@@ -61,7 +57,7 @@ struct _GtkSourceMarkAttributesClass
 	/*< private >*/
 	GObjectClass parent_class;
 
-	/*< public >*/
+	gpointer padding[10];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
@@ -78,13 +74,6 @@ GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean         gtk_source_mark_attributes_get_background      (GtkSourceMarkAttributes *attributes,
                                                                  GdkRGBA                 *background);
 
-GTK_SOURCE_DEPRECATED_IN_3_10
-void             gtk_source_mark_attributes_set_stock_id        (GtkSourceMarkAttributes *attributes,
-                                                                 const gchar             *stock_id);
-
-GTK_SOURCE_DEPRECATED_IN_3_10
-const gchar     *gtk_source_mark_attributes_get_stock_id        (GtkSourceMarkAttributes *attributes);
-
 GTK_SOURCE_AVAILABLE_IN_ALL
 void             gtk_source_mark_attributes_set_icon_name       (GtkSourceMarkAttributes *attributes,
                                                                  const gchar             *icon_name);
