@@ -22,6 +22,10 @@
 #ifndef GTK_SOURCE_STYLE_SCHEME_H
 #define GTK_SOURCE_STYLE_SCHEME_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
 
@@ -48,8 +52,7 @@ struct _GtkSourceStyleSchemeClass
 	GObjectClass base_class;
 
 	/* Padding for future expansion */
-	void (*_gtk_source_reserved1) (void);
-	void (*_gtk_source_reserved2) (void);
+	gpointer padding[10];
 };
 
 GTK_SOURCE_AVAILABLE_IN_ALL
