@@ -22,6 +22,10 @@
 #ifndef GTK_SOURCE_UTILS_H
 #define GTK_SOURCE_UTILS_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#error "Only <gtksourceview/gtksource.h> can be included directly."
+#endif
+
 #include <glib-object.h>
 #include <gtksourceview/gtksourceversion.h>
 
