@@ -25,11 +25,7 @@
 #define GTK_SOURCE_VIEW_H
 
 #if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
-#  if defined (__GNUC__)
-#    warning "Only <gtksourceview/gtksource.h> can be included directly."
-#  elif defined (G_OS_WIN32)
-#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
-#  endif
+#error "Only <gtksourceview/gtksource.h> can be included directly."
 #endif
 
 #include <gtk/gtk.h>
@@ -54,12 +50,45 @@ typedef struct _GtkSourceViewPrivate GtkSourceViewPrivate;
  * @GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS: the gutter position of the marks
  * renderer
  */
-typedef enum
+typedef enum _GtkSourceViewGutterPosition
 {
 	GTK_SOURCE_VIEW_GUTTER_POSITION_LINES = -30,
 	GTK_SOURCE_VIEW_GUTTER_POSITION_MARKS = -20
 } GtkSourceViewGutterPosition;
 
+/**
+ * GtkSourceSmartHomeEndType:
+ * @GTK_SOURCE_SMART_HOME_END_DISABLED: smart-home-end disabled.
+ * @GTK_SOURCE_SMART_HOME_END_BEFORE: move to the first/last
+ * non-whitespace character on the first press of the HOME/END keys and
+ * to the beginning/end of the line on the second press.
+ * @GTK_SOURCE_SMART_HOME_END_AFTER: move to the beginning/end of the
+ * line on the first press of the HOME/END keys and to the first/last
+ * non-whitespace character on the second press.
+ * @GTK_SOURCE_SMART_HOME_END_ALWAYS: always move to the first/last
+ * non-whitespace character when the HOME/END keys are pressed.
+ */
+typedef enum _GtkSourceSmartHomeEndType
+{
+	GTK_SOURCE_SMART_HOME_END_DISABLED,
+	GTK_SOURCE_SMART_HOME_END_BEFORE,
+	GTK_SOURCE_SMART_HOME_END_AFTER,
+	GTK_SOURCE_SMART_HOME_END_ALWAYS
+} GtkSourceSmartHomeEndType;
+
+/**
+ * GtkSourceBackgroundPatternType:
+ * @GTK_SOURCE_BACKGROUND_PATTERN_TYPE_NONE: no pattern
+ * @GTK_SOURCE_BACKGROUND_PATTERN_TYPE_GRID: grid pattern
+ *
+ * Since: 3.16
+ */
+typedef enum _GtkSourceBackgroundPatternType
+{
+	GTK_SOURCE_BACKGROUND_PATTERN_TYPE_NONE,
+	GTK_SOURCE_BACKGROUND_PATTERN_TYPE_GRID
+} GtkSourceBackgroundPatternType;
+
 struct _GtkSourceView
 {
 	GtkTextView parent;
@@ -85,56 +114,9 @@ struct _GtkSourceViewClass
 	                    gint           step);
 
 	/* Padding for future expansion */
+	gpointer padding[20];
 };
 
-/**
- * GtkSourceSmartHomeEndType:
- * @GTK_SOURCE_SMART_HOME_END_DISABLED: smart-home-end disabled.
- * @GTK_SOURCE_SMART_HOME_END_BEFORE: move to the first/last
- * non-whitespace character on the first press of the HOME/END keys and
- * to the beginning/end of the line on the second press.
- * @GTK_SOURCE_SMART_HOME_END_AFTER: move to the beginning/end of the
- * line on the first press of the HOME/END keys and to the first/last
- * non-whitespace character on the second press.
- * @GTK_SOURCE_SMART_HOME_END_ALWAYS: always move to the first/last
- * non-whitespace character when the HOME/END keys are pressed.
- */
-typedef enum
-{
-	GTK_SOURCE_SMART_HOME_END_DISABLED,
-	GTK_SOURCE_SMART_HOME_END_BEFORE,
-	GTK_SOURCE_SMART_HOME_END_AFTER,
-	GTK_SOURCE_SMART_HOME_END_ALWAYS
-} GtkSourceSmartHomeEndType;
-
-/**
- * GtkSourceDrawSpacesFlags:
- * @GTK_SOURCE_DRAW_SPACES_SPACE: whether the space character should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_TAB: whether the tab character should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_NEWLINE: whether the line breaks should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_NBSP: whether the non-breaking whitespaces should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_LEADING: whether leading whitespaces should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_TEXT: whether whitespaces inside text should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_TRAILING: whether trailing whitespaces should be drawn.
- * @GTK_SOURCE_DRAW_SPACES_ALL: wheter all kind of spaces should be drawn.
- *
- * GtkSourceDrawSpacesFlags determine what kind of spaces whould be drawn. If none
- * of GTK_SOURCE_DRAW_SPACES_LEADING, GTK_SOURCE_DRAW_SPACES_TEXT or
- * GTK_SOURCE_DRAW_SPACES_TRAILING is specified, whitespaces at any position in
- * the line will be drawn (i.e. it has the same effect as specifying all of them).
- */
-typedef enum
-{
-	GTK_SOURCE_DRAW_SPACES_SPACE      = 1 << 0,
-	GTK_SOURCE_DRAW_SPACES_TAB        = 1 << 1,
-	GTK_SOURCE_DRAW_SPACES_NEWLINE    = 1 << 2,
-	GTK_SOURCE_DRAW_SPACES_NBSP       = 1 << 3,
-	GTK_SOURCE_DRAW_SPACES_LEADING    = 1 << 4,
-	GTK_SOURCE_DRAW_SPACES_TEXT       = 1 << 5,
-	GTK_SOURCE_DRAW_SPACES_TRAILING   = 1 << 6,
-	GTK_SOURCE_DRAW_SPACES_ALL        = 0x7f
-} GtkSourceDrawSpacesFlags;
-
 GTK_SOURCE_AVAILABLE_IN_ALL
 GType		 gtk_source_view_get_type		(void) G_GNUC_CONST;
 
@@ -257,14 +239,6 @@ GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceSmartHomeEndType
 		 gtk_source_view_get_smart_home_end	(GtkSourceView   *view);
 
-GTK_SOURCE_AVAILABLE_IN_ALL
-void		 gtk_source_view_set_draw_spaces	(GtkSourceView            *view,
-							 GtkSourceDrawSpacesFlags  flags);
-
-GTK_SOURCE_AVAILABLE_IN_ALL
-GtkSourceDrawSpacesFlags
-		 gtk_source_view_get_draw_spaces	(GtkSourceView   *view);
-
 GTK_SOURCE_AVAILABLE_IN_ALL
 guint		 gtk_source_view_get_visual_column	(GtkSourceView     *view,
 							 const GtkTextIter *iter);
@@ -285,6 +259,10 @@ GTK_SOURCE_AVAILABLE_IN_3_16
 GtkSourceBackgroundPatternType
 		 gtk_source_view_get_background_pattern	(GtkSourceView   *view);
 
+GTK_SOURCE_AVAILABLE_IN_3_24
+GtkSourceSpaceDrawer *
+		 gtk_source_view_get_space_drawer	(GtkSourceView   *view);
+
 G_END_DECLS
 
 #endif /* end of GTK_SOURCE_VIEW_H */
