@@ -29,7 +29,7 @@
  * - regex search.
  *
  * For the "smart" search, only the first search is measured. Later searches
- * are really fast (going to the previous/next occurrence is done in O(1)).
+ * are really fast (going to the previous/next occurrence is done in O(log n)).
  * Different search flags are also tested. We can see a big difference between
  * the case sensitive search and case insensitive.
  */
@@ -136,12 +136,11 @@ main (int argc, char *argv[])
 
 	g_timer_start (timer);
 
-	gtk_source_search_settings_set_wrap_around (search_settings, FALSE);
 	gtk_source_search_settings_set_search_text (search_settings, "foo");
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -160,7 +159,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -179,7 +178,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -196,7 +195,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -213,7 +212,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -233,7 +232,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
@@ -252,7 +251,7 @@ main (int argc, char *argv[])
 
 	gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
 
-	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end))
+	while (gtk_source_search_context_forward (search_context, &iter, NULL, &match_end, NULL))
 	{
 		iter = match_end;
 	}
