@@ -147,7 +147,7 @@ update_label_regex_error (TestSearch *search)
 	{
 		gtk_label_set_text (search->priv->label_regex_error, error->message);
 		gtk_widget_show (GTK_WIDGET (search->priv->label_regex_error));
-		g_error_free (error);
+		g_clear_error (&error);
 	}
 }
 
@@ -191,6 +191,7 @@ backward_search_finished (GtkSourceSearchContext *search_context,
 						       result,
 						       &match_start,
 						       &match_end,
+						       NULL,
 						       NULL))
 	{
 		select_search_occurrence (search, &match_start, &match_end);
@@ -226,6 +227,7 @@ forward_search_finished (GtkSourceSearchContext *search_context,
 						      result,
 						      &match_start,
 						      &match_end,
+						      NULL,
 						      NULL))
 	{
 		select_search_occurrence (search, &match_start, &match_end);
