@@ -367,6 +367,7 @@ test_search_at_word_boundaries (void)
 	GtkTextBuffer *text_buffer = GTK_TEXT_BUFFER (source_buffer);
 	GtkSourceSearchSettings *settings = gtk_source_search_settings_new ();
 	GtkSourceSearchContext *context = gtk_source_search_context_new (source_buffer, settings);
+	GtkTextIter iter;
 	gboolean at_word_boundaries;
 	gint occurrences_count;
 
@@ -381,13 +382,27 @@ test_search_at_word_boundaries (void)
 	occurrences_count = gtk_source_search_context_get_occurrences_count (context);
 	g_assert_cmpint (occurrences_count, ==, 1);
 
+	/* Contents: "AtWordBoundaries AtWord AtWord" */
+	gtk_text_buffer_get_iter_at_offset (text_buffer, &iter, 16);
+	gtk_text_buffer_insert (text_buffer, &iter, " AtWord", -1);
+	flush_queue ();
+	occurrences_count = gtk_source_search_context_get_occurrences_count (context);
+	g_assert_cmpint (occurrences_count, ==, 2);
+
+	/* Contents: "AtWordBoundaries AtWordd AtWord" */
+	gtk_text_buffer_get_iter_at_offset (text_buffer, &iter, 23);
+	gtk_text_buffer_insert (text_buffer, &iter, "d", -1);
+	flush_queue ();
+	occurrences_count = gtk_source_search_context_get_occurrences_count (context);
+	g_assert_cmpint (occurrences_count, ==, 1);
+
 	gtk_source_search_settings_set_at_word_boundaries (settings, FALSE);
 	at_word_boundaries = gtk_source_search_settings_get_at_word_boundaries (settings);
 	g_assert (!at_word_boundaries);
 
 	flush_queue ();
 	occurrences_count = gtk_source_search_context_get_occurrences_count (context);
-	g_assert_cmpint (occurrences_count, ==, 2);
+	g_assert_cmpint (occurrences_count, ==, 3);
 
 	/* Word with underscores */
 
@@ -432,20 +447,20 @@ check_search_results (GtkSourceBuffer        *source_buffer,
 
 		if (forward)
 		{
-			found = gtk_source_search_context_forward2 (context,
+			found = gtk_source_search_context_forward (context,
+								   &iter,
+								   &match_start,
+								   &match_end,
+								   &has_wrapped_around);
+		}
+		else
+		{
+			found = gtk_source_search_context_backward (context,
 								    &iter,
 								    &match_start,
 								    &match_end,
 								    &has_wrapped_around);
 		}
-		else
-		{
-			found = gtk_source_search_context_backward2 (context,
-								     &iter,
-								     &match_start,
-								     &match_end,
-								     &has_wrapped_around);
-		}
 
 		g_assert_cmpint (found, ==, results[i].found);
 		g_assert_cmpint (has_wrapped_around, ==, results[i].has_wrapped_around);
@@ -475,22 +490,22 @@ finish_check_result (GtkSourceSearchContext *context,
 
 	if (data->forward)
 	{
-		found = gtk_source_search_context_forward_finish2 (context,
+		found = gtk_source_search_context_forward_finish (context,
+								  result,
+								  &match_start,
+								  &match_end,
+								  &has_wrapped_around,
+								  NULL);
+	}
+	else
+	{
+		found = gtk_source_search_context_backward_finish (context,
 								   result,
 								   &match_start,
 								   &match_end,
 								   &has_wrapped_around,
 								   NULL);
 	}
-	else
-	{
-		found = gtk_source_search_context_backward_finish2 (context,
-								    result,
-								    &match_start,
-								    &match_end,
-								    &has_wrapped_around,
-								    NULL);
-	}
 
 	g_assert_cmpint (found, ==, search_result.found);
 	g_assert_cmpint (has_wrapped_around, ==, search_result.has_wrapped_around);
@@ -903,13 +918,13 @@ test_replace (void)
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &start, 1);
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &end, 3);
 
-	replaced = gtk_source_search_context_replace2 (context, &start, &end, "bbb", -1, NULL);
+	replaced = gtk_source_search_context_replace (context, &start, &end, "bbb", -1, NULL);
 	g_assert (!replaced);
 
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &start, 2);
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &end, 4);
 
-	replaced = gtk_source_search_context_replace2 (context, &start, &end, "bbb", -1, NULL);
+	replaced = gtk_source_search_context_replace (context, &start, &end, "bbb", -1, NULL);
 	g_assert (replaced);
 	offset = gtk_text_iter_get_offset (&start);
 	g_assert_cmpint (offset, ==, 2);
@@ -991,7 +1006,7 @@ test_regex_basics (void)
 
 	gtk_text_buffer_get_start_iter (text_buffer, &start);
 	gtk_text_buffer_get_end_iter (text_buffer, &end);
-	gtk_source_search_context_replace2 (context, &start, &end, "\\2#\\1", -1, NULL);
+	gtk_source_search_context_replace (context, &start, &end, "\\2#\\1", -1, NULL);
 	g_assert (gtk_text_iter_is_start (&start));
 	g_assert (gtk_text_iter_is_end (&end));
 
@@ -1036,11 +1051,11 @@ test_regex_at_word_boundaries (void)
 
 	gtk_text_buffer_get_start_iter (text_buffer, &iter);
 
-	found = gtk_source_search_context_forward2 (context,
-						    &iter,
-						    &match_start,
-						    &match_end,
-						    &has_wrapped_around);
+	found = gtk_source_search_context_forward (context,
+						   &iter,
+						   &match_start,
+						   &match_end,
+						   &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1050,11 +1065,11 @@ test_regex_at_word_boundaries (void)
 	g_assert_cmpint (offset, ==, 4);
 
 	iter = match_end;
-	found = gtk_source_search_context_forward2 (context,
-						    &iter,
-						    &match_start,
-						    &match_end,
-						    &has_wrapped_around);
+	found = gtk_source_search_context_forward (context,
+						   &iter,
+						   &match_start,
+						   &match_end,
+						   &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1071,7 +1086,7 @@ test_regex_at_word_boundaries (void)
 
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &match_start, 1);
 	gtk_text_buffer_get_end_iter (text_buffer, &match_end);
-	gtk_source_search_context_replace2 (context, &match_start, &match_end, "bbb", -1, NULL);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "bbb", -1, NULL);
 	offset = gtk_text_iter_get_offset (&match_start);
 	g_assert_cmpint (offset, ==, 1);
 	g_assert (gtk_text_iter_is_end (&match_end));
@@ -1088,7 +1103,7 @@ test_regex_at_word_boundaries (void)
 
 	gtk_text_buffer_get_iter_at_offset (text_buffer, &match_start, 1);
 	gtk_text_buffer_get_end_iter (text_buffer, &match_end);
-	gtk_source_search_context_replace2 (context, &match_start, &match_end, "bbb", -1, NULL);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "bbb", -1, NULL);
 	offset = gtk_text_iter_get_offset (&match_start);
 	g_assert_cmpint (offset, ==, 1);
 	g_assert (gtk_text_iter_is_end (&match_end));
@@ -1132,11 +1147,11 @@ test_regex_look_behind (void)
 
 	/* Forward search */
 	gtk_text_buffer_get_start_iter (text_buffer, &iter);
-	found = gtk_source_search_context_forward2 (context,
-						    &iter,
-						    &match_start,
-						    &match_end,
-						    &has_wrapped_around);
+	found = gtk_source_search_context_forward (context,
+						   &iter,
+						   &match_start,
+						   &match_end,
+						   &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1147,11 +1162,11 @@ test_regex_look_behind (void)
 
 	/* Backward search */
 	gtk_text_buffer_get_end_iter (text_buffer, &iter);
-	found = gtk_source_search_context_backward2 (context,
-						     &iter,
-						     &match_start,
-						     &match_end,
-						     &has_wrapped_around);
+	found = gtk_source_search_context_backward (context,
+						    &iter,
+						    &match_start,
+						    &match_end,
+						    &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1165,7 +1180,7 @@ test_regex_look_behind (void)
 	g_assert_cmpint (pos, ==, 1);
 
 	/* Replace */
-	gtk_source_search_context_replace2 (context, &match_start, &match_end, "R", -1, &error);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "R", -1, &error);
 	g_assert_no_error (error);
 
 	contents = get_buffer_contents (text_buffer);
@@ -1218,11 +1233,11 @@ test_regex_look_ahead (void)
 
 	/* Forward search */
 	gtk_text_buffer_get_start_iter (text_buffer, &iter);
-	found = gtk_source_search_context_forward2 (context,
-						    &iter,
-						    &match_start,
-						    &match_end,
-						    &has_wrapped_around);
+	found = gtk_source_search_context_forward (context,
+						   &iter,
+						   &match_start,
+						   &match_end,
+						   &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1233,11 +1248,11 @@ test_regex_look_ahead (void)
 
 	/* Backward search */
 	gtk_text_buffer_get_end_iter (text_buffer, &iter);
-	found = gtk_source_search_context_backward2 (context,
-						     &iter,
-						     &match_start,
-						     &match_end,
-						     &has_wrapped_around);
+	found = gtk_source_search_context_backward (context,
+						    &iter,
+						    &match_start,
+						    &match_end,
+						    &has_wrapped_around);
 	g_assert (found);
 	g_assert (!has_wrapped_around);
 
@@ -1251,7 +1266,7 @@ test_regex_look_ahead (void)
 	g_assert_cmpint (pos, ==, 1);
 
 	/* Replace */
-	gtk_source_search_context_replace2 (context, &match_start, &match_end, "R", -1, &error);
+	gtk_source_search_context_replace (context, &match_start, &match_end, "R", -1, &error);
 	g_assert_no_error (error);
 
 	contents = get_buffer_contents (text_buffer);
